@@ -48,6 +48,7 @@ class NextPictureManager:
         self.cur_pic_num += 1
         if os.path.exists(cur_pic.absolute_path):
             self._inc_times_shown(cur_pic)
+            log.debug(f"{cur_pic.absolute_path} chosen to be shown as next picture.")
             return cur_pic
         else:
             return self.get_next_picture()
@@ -89,9 +90,16 @@ class NextPictureManager:
                 + 1
                 for x in nums_shown
             ]
+            log.debug(
+                f"The first 100 weights out of {len(weights)} are {weights[:100]}."
+            )
             sample_list = random.choices(
                 full_picture_list, weights=weights, k=len(full_picture_list)
             )
+            log.debug(
+                f"The first 100 pictures out of {len(sample_list)} are "
+                f"{[x.absolute_path for x in sample_list[:100]]}."
+            )
         return sample_list
 
     def _load_pictures_from_db(self) -> Optional[List[PictureData]]:
