@@ -6,6 +6,8 @@ from pipictureframe.picdb.DbObjects import Metadata
 from pipictureframe.picdb.PictureUpdater import PictureData
 from pipictureframe.picdb.Database import LAST_DB_UPDATE_FMT_STR
 
+dt_now = datetime.now()
+
 
 def get_config_mock(shuffle=False, shuffle_weight=0):
     config = Mock()
@@ -20,12 +22,12 @@ def get_config_mock(shuffle=False, shuffle_weight=0):
     return config
 
 
-def get_db_mock(return_pics: List[PictureData] = list()):
+def get_db_mock(return_pics: List[PictureData], update_time=dt_now):
     query = Mock()
     query.filter = Mock(return_value=query)
     query.all = Mock(return_value=return_pics)
     query.one = Mock(
-        return_value=Metadata("x", datetime.now().strftime(LAST_DB_UPDATE_FMT_STR))
+        return_value=Metadata("x", update_time.strftime(LAST_DB_UPDATE_FMT_STR))
     )
     session = Mock()
     session.query = Mock(return_value=query)
